%% load and sort data

data = load('FrankeEtAl_BCs_2017_v1.mat');

cI = data.cluster_idx;

gchirp = []; rf_tc = []; steps = []; lchirp = [];

names = {'CBC1', 'CBC2', 'CBC3A', 'CBC3B', 'CBC4', 'CBC5A', 'CBC5R', ...
            'CBC5X', 'XBC', 'CBC6', 'CBC7', 'CBC8', 'CBC9', 'RBC'};

K = length(names);
nCellsPerType = zeros(K,1);
                
for ii = 1:K
    tt = data.gchirp_avg(:,cI==ii);
    rf = data.rf_tc(:,cI==ii);
    st = data.step_avg(:,cI==ii);
    tl = data.lchirp_avg(:,cI==ii);
    
    p = data.roi_depth(cI==ii);
    [~, bidx] = sort(p,'descend');
    gchirp = [gchirp tt(:,bidx)]; %#ok<AGROW>
    lchirp = [lchirp tl(:,bidx)]; %#ok<AGROW>
    rf_tc = [rf_tc rf(:,bidx)];
    steps = [steps st(:,bidx)];
    nCellsPerType(ii) = sum(cI==ii);
    
    gchirp_mean(:,ii) = mean(tt,2);
    lchirp_mean(:,ii) = mean(tl,2);
    step_mean(:,ii) = mean(st,2);
    
end

%% plot bc type means

figure
t = data.chirp_time;

% ----------
subplot(5,3,1)
plot(t,lchirp_mean(:,1))
hold on
plot(t,lchirp_mean(:,2))
xlim([0 32])
ylim([-.5 1])
ylabel('BC 1/2')
title('Local chirp')
set(gca,'box','off')

subplot(5,3,2)
plot(t,gchirp_mean(:,1))
hold on
plot(t,gchirp_mean(:,2))
xlim([0 32])
ylim([-.5 1])
title('Full-field chirp')
set(gca,'box','off')

subplot(5,3,3)
plot(t,gchirp_mean(:,1))
hold on
plot(t,gchirp_mean(:,2))
xlim([1.5 6])
ylim([-.5 1])
title('Full- field chirp')
set(gca,'box','off')

% ----------

subplot(5,3,4)
plot(t,lchirp_mean(:,3))
hold on
plot(t,lchirp_mean(:,4))
plot(t,lchirp_mean(:,5))
xlim([0 32])
ylim([-.5 1])
ylabel('BC 3a/3b/4')
set(gca,'box','off')

subplot(5,3,5)
plot(t,gchirp_mean(:,3))
hold on
plot(t,gchirp_mean(:,4))
plot(t,gchirp_mean(:,5))
xlim([0 32])
ylim([-.5 1])
set(gca,'box','off')

subplot(5,3,6)
plot(t,gchirp_mean(:,3))
hold on
plot(t,gchirp_mean(:,4))
plot(t,gchirp_mean(:,5))
xlim([1.5 6])
ylim([-.5 1])
set(gca,'box','off')


% -------

subplot(5,3,7)
plot(t,lchirp_mean(:,6))
hold on
plot(t,lchirp_mean(:,7))
plot(t,lchirp_mean(:,8))
plot(t,lchirp_mean(:,9))
xlim([0 32])
ylim([-.5 1])
ylabel('BC 5i, 5o, 5r, X')
set(gca,'box','off')


subplot(5,3,8)
plot(t,gchirp_mean(:,6))
hold on
plot(t,gchirp_mean(:,7))
plot(t,gchirp_mean(:,8))
plot(t,gchirp_mean(:,9))
xlim([0 32])
ylim([-.5 1])
set(gca,'box','off')


subplot(5,3,9)
plot(t,gchirp_mean(:,6))
hold on
plot(t,gchirp_mean(:,7))
plot(t,gchirp_mean(:,8))
plot(t,gchirp_mean(:,9))

xlim([1.5 6])
ylim([-.5 1])
set(gca,'box','off')


% -----

subplot(5,3,10)
plot(t,lchirp_mean(:,10))
hold on
plot(t,lchirp_mean(:,11))
xlim([0 32])
ylim([-.5 1])
ylabel('BC 6, 7')
set(gca,'box','off')


subplot(5,3,11)
plot(t,gchirp_mean(:,10))
hold on
plot(t,gchirp_mean(:,11))
xlim([0 32])
ylim([-.5 1])
set(gca,'box','off')


subplot(5,3,12)
plot(t,gchirp_mean(:,10))
hold on
plot(t,gchirp_mean(:,11))
xlim([1.5 6])
ylim([-.5 1])
set(gca,'box','off')


% -------

subplot(5,3,13)
plot(t,lchirp_mean(:,12))
hold on
plot(t,lchirp_mean(:,13))
plot(t,lchirp_mean(:,14))
xlim([0 32])
ylim([-.5 1])
ylabel('8, 9, R')
xlabel('Time (s)')
set(gca,'box','off')

subplot(5,3,14)
plot(t,gchirp_mean(:,12))
hold on
plot(t,gchirp_mean(:,13))
plot(t,gchirp_mean(:,14))
xlim([0 32])
ylim([-.5 1])
xlabel('Time (s)')
set(gca,'box','off')

subplot(5,3,15)
plot(t,gchirp_mean(:,12))
hold on
plot(t,gchirp_mean(:,13))
plot(t,gchirp_mean(:,14))
xlim([1.5 6])
ylim([-.5 1])
xlabel('Time (s)')
set(gca,'box','off')

%% plot data
figure
last = [0; cumsum(nCellsPerType)];

% local chirp
subplot(1,5,1:2)
imagesc(data.chirp_time,1:sum(nCellsPerType),lchirp',[-1 1])

for ii=2:length(nCellsPerType)
    if nCellsPerType(ii)>0
        line([0 data.chirp_time(end)],[last(ii) last(ii)],'color','k')
    end
end

xlabel('Time (s)')
ylabel('ROIs')
title('Local chirp')

tick = unique(ceil(last(1:end-1) + diff(last)/2));
set(gca,'ytick',tick,'yticklabels',names)

% global chirp
subplot(1,5,3:4)
imagesc(data.chirp_time,1:sum(nCellsPerType),gchirp',[-1 1])

for ii=2:length(nCellsPerType)
    if nCellsPerType(ii)>0
        line([0 data.chirp_time(end)],[last(ii) last(ii)],'color','k')
    end
end

xlabel('Time (s)')
title('Full-field chirp')
set(gca,'ytick',[])

% step
subplot(1,5,5)
imagesc(data.step_time,1:sum(nCellsPerType),steps',[-1 1])

for ii=2:length(nCellsPerType)
    if nCellsPerType(ii)>0
        line([data.step_time(1) data.step_time(end)],[last(ii) last(ii)],'color','k')
    end
end

xlabel('Time (s)')
set(gca,'ytick',[])
title('Step')


